c**********************************************************************
c  EXTERNAL RMC MOVE SUBROUTINE
c
c  This subroutine is called by DISCUS during RMC refinements if the
c  mode is set to external using the command 'set mode,external' in
c  the RMC sublevel.
c
c  All parameters passed to the subroutine are output values, i.e.
c  must be set by the subroutine. All information about crystal,
c  RMC settings, etc. are supplied via COMMON blocks through the
c  include statements. Do not change any of those values !!
c
c**********************************************************************
c  1. Output parameters of 'rmc_genmove_ext'
c  -----------------------------------------
c
c  l   laccept         : TRUE if the generated move is valid,
c                        FALSE otherwise. Just generating ONE move in 
c                        this routine and use 'laccept' to indicate a 
c                        valid configuration. This will keep 'number of 
c                        generated moves' correct.
c  i   natoms          : Number of atoms modified
c  r   p_new(3,natoms) : New positions x,y,z of selected atoms
c  i   i_new(natoms)   : New atom type of selected atoms
c  i   isel(natoms)    : Number of selected atoms within crystal
c 
c**********************************************************************
c  2.   List of variables defining crystal and RMC settings
c  --------------------------------------------------------
c
c  2.1. crystal.inc
c  ----------------
c
c  i   cr_natoms          : Number of atoms in crystal
c  i   cr_ncatoms         : Number of atoms per unit cell
c  i   cr_nscat           : Number of different atom types
c                           Note: VOID is typ 0 !
c  i   cr_icc(3)          : Number of unit cells in x,y,z direction
c  i   cr_iscat(atoms)    : Gives atom typ for atom 'iatom'
c   
c  r   cr_a0(3)           : Contains lattice constants a,b,c
c  r   cr_win(3)          : Contains angles alfa,beta,gamma
c  r   cr_gten(3,3)       : Contains metric tensor
c  r   cr_rten(3,3)       : Contains reciprocal metric tensor
c  r   cr_pos(3,iatom)    : Position x,y,z of atom 'iatom' in crystal
c  r   cr_dim(3,2)        : Crystal dimension (x,y,z | min,max)
c  
c  c16 cr_spcgr           : CHARACTER containing space group symbol
c  c4  cr_at_lis(ityp)    : CHARACTER containing atom name for atom
c                           type 'ityp'.
c
c  2.2. rmc.inc
c  ------------
c
c  r   rmc_maxmove(3,ityp)   : Value sx,sy,sz for atom type 'ityp' set
c                              with 'set move,..' command.
c  r   rmc_mindist(ityp,jtyp): Minimal allowed distance between atom
c                              types 'ityp' and 'jtyp'.
c  l   rmc_allowed(ityp)     : TRUE is atom type 'ityp' is selected for
c                              RMC refinement ('sele' command)
c
c  2.3. chem.inc
c  -------------
c
c  r   chem_ave_pos(3,isite) : Average position x,y,z of site 'isite'
c  r   chem_ave_sig(3,isite) : Standard deviation sx,sy,sz of 'isite'
c 
c**********************************************************************
c  3. Useful subroutines supplied by DISCUS
c  ----------------------------------------
c
c  real function ran1(idum):
c  -------------------------
c    Gives random number [0,1]. The parameter 'idum' is defined in
c    'random.inc'. The random generator is initialised before RMC level
c    is entered.
c
c  real function gasdev(sigma):
c  ----------------------------
c    Gives Gaussian distributed random number. FWHM of the distribution
c    is given by the parameter 'sigma'.
c
c  real function do_bang(lspace,u(3),v(3),w(3)):
c  ---------------------------------------------
c    Gives the angle between vector v-u and v-w in space defined by
c    lspace (.true. = real space , .false. = reciprocal space) 
c
c  real function do_blen(lspace,u(3),v(3)):
c  ----------------------------------------
c    Calculates the length of the vector v-u in the space defined by 
c    lspace (.true. = real space , .false. = reciprocal space) 
c
c  subroutine indextocell (iatom,icell(3),isite)
c  ---------------------------------------------
c    Gives number of unit cell 'icell(3)' and atom site number 'isite'
c    for the atom index 'iatom'. This routine works only properly, if
c    the supplied structure is given in the order specified in the 
c    the DISCUS manual.
c
c  subroutine celltoindex (icell(3),isite,iatom)
c  ---------------------------------------------
c    Gives the atom index for unit cell 'icell(3)' and site 'isite'.
c    Again the structure must be given in the 'DISCUS order' to be able
c    to use this routine.
c
c**********************************************************************
c**********************************************************************
c
	subroutine rmc_genmove_ext (laccept,natoms,p_new,i_new,isel) 
c
c------ We recommend 'implicit none' to avoid the accidental use
c------ of DISCUS variables defined in the include files
c
	implicit none
c
c------ Include files containing array sizes, crystal definitions,
c------ error and RMC variables
c
	include		'config.inc'
	include		'crystal.inc'
	include		'crystal.cmm'
	include		'errlist.inc'
	include		'random.inc'
	include		'chem.inc'
	include		'rmc.inc'
c
c------ Declaration of the variables passed down from DISCUS. 
c------ All information must be passed on via these variables, do
c------ NOT change any other DISCUS variables !
c
	real		p_new(3,rmc_max_atom)
	integer		i_new(rmc_max_atom)
	integer		isel(rmc_max_atom)
	integer		natoms
	logical		laccept
c
c**********************************************************************
c  Here is as an example the part of the code for shifting a single
c  atom. This is exactly what mode SHIFT does. Remove the code, or
c  modify it to your needs. For more examples, have a look at the
c  subroutine 'rmc_genmove' in the source file 'rmc.f'.
c**********************************************************************
c
c------ declaration of local variables, functions (-> implicit none)
c
	integer		i
	real		ran1,gasdev
c
c------ we will modify just ONE atom
c
	natoms = 1
c
c------ we select one atom at random, 
c------ 'idum' is defined in 'random.inc'
c
	isel(1) = int(ran1(idum)*cr_natoms)+1
c
c------ set new atom type number, here is is unchanged
c
	i_new(1) = cr_iscat(isel(1)) 
c
c------ Check if the selected atom is on the list of
c------ selected atoms set by the command 'sele'
c
	laccept = rmc_allowed(i_new(1))
c
c------ if we have a valid atom, move it. The real function
c------ 'gasdev' generates Gaussian distributed random number.
c------ 'rmc_maxmove' contains the FWHM of the distribution
c------ set by the command 'set move,...'
c
	if (laccept) then
	  do i=1,3
	    p_new(i,1) = cr_pos(i,isel(1)) +
     &	                 gasdev(rmc_maxmove(i,i_new(1)))
	  enddo
	endif
c
c------ We don't have to worry here about moving atoms too close
c------ together, this is checked in the main RMC routine.
c
	end
